@@ -30,6 +30,7 @@
 #include <libpanel-util/panel-glib.h>
 
 #include "launcher.h"
+#include "menu.h"
 #include "panel.h"
 #include "panel-applets-manager.h"
 #include "panel-applet-frame.h"
@@ -653,6 +654,7 @@ panel_addto_make_application_model (PanelAddtoDialog *dialog)
 	GtkTreeStore      *store;
 	GMenuTree          *tree;
 	GMenuTreeDirectory *root;
+	gchar              *applications_menu;
 
 	if (dialog->filter_application_model != NULL)
 		return;
@@ -663,7 +665,8 @@ panel_addto_make_application_model (PanelAddtoDialog *dialog)
 				    G_TYPE_POINTER,
 				    G_TYPE_STRING);
 
-	tree = gmenu_tree_new ("gnome-applications.menu", GMENU_TREE_FLAGS_SORT_DISPLAY_NAME);
+	applications_menu = get_applications_menu ();
+	tree = gmenu_tree_new (applications_menu, GMENU_TREE_FLAGS_SORT_DISPLAY_NAME);
 
 	if (!gmenu_tree_load_sync (tree, NULL)) {
 		g_object_unref (tree);
@@ -672,13 +675,15 @@ panel_addto_make_application_model (PanelAddtoDialog *dialog)
 
 	if (tree != NULL && (root = gmenu_tree_get_root_directory (tree))) {
 		panel_addto_make_application_list (&dialog->application_list,
-						   root, "gnome-applications.menu",
+						   root, applications_menu,
 						   PANEL_ADDTO_MENU_SHOW_ALL);
 		panel_addto_populate_application_model (store, NULL, dialog->application_list);
 
 		gmenu_tree_item_unref (root);
 	}
 
+	g_free (applications_menu);
+
 	if (tree != NULL)
 		g_object_unref (tree);
 
@@ -1138,13 +1143,11 @@ panel_addto_selection_changed (GtkTreeSelection *selection,
 
 	if (data->type == PANEL_ADDTO_LAUNCHER_MENU) {
 		gtk_button_set_label (GTK_BUTTON (dialog->add_button),
-				      GTK_STOCK_GO_FORWARD);
+				      _("_Forward"));
 	} else {
 		gtk_button_set_label (GTK_BUTTON (dialog->add_button),
-				      GTK_STOCK_ADD);
+				      _("_Add"));
 	}
-	gtk_button_set_use_stock (GTK_BUTTON (dialog->add_button),
-				  TRUE);
 
 	/* only allow dragging applets if we can add applets */
 	if (panel_layout_is_writable ()) {
@@ -1236,13 +1239,13 @@ panel_addto_dialog_new (PanelWidget *panel_widget)
 
 	dialog->addto_dialog = gtk_dialog_new ();
 	dialog->back_button = gtk_dialog_add_button (GTK_DIALOG (dialog->addto_dialog),
-						     GTK_STOCK_GO_BACK,
+						     _("_Back"),
 						     PANEL_ADDTO_RESPONSE_BACK);
 	dialog->add_button = gtk_dialog_add_button (GTK_DIALOG (dialog->addto_dialog),
-						     GTK_STOCK_ADD,
+						     _("_Add"),
 						     PANEL_ADDTO_RESPONSE_ADD);
 	gtk_dialog_add_button (GTK_DIALOG (dialog->addto_dialog),
-			       GTK_STOCK_CLOSE,
+			       _("_Close"),
 			       GTK_RESPONSE_CLOSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (dialog->add_button), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->addto_dialog),
@@ -1266,7 +1269,7 @@ panel_addto_dialog_new (PanelWidget *panel_widget)
 	gtk_box_pack_start (GTK_BOX (inner_vbox), find_hbox, FALSE, FALSE, 0);
 
 	dialog->label = gtk_label_new_with_mnemonic ("");
-	gtk_misc_set_alignment (GTK_MISC (dialog->label), 0.0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (dialog->label), 0.0);
 	gtk_label_set_use_markup (GTK_LABEL (dialog->label), TRUE);
 
 	gtk_box_pack_start (GTK_BOX (find_hbox), dialog->label,
