@@ -108,50 +108,23 @@ panel_orient_change (GtkWidget *widget, gpointer data)
 			      widget);
 }
 
-/*we call this recursively*/
-static void size_change_foreach(GtkWidget *w, gpointer data);
-
-void
-size_change (AppletInfo  *info,
-	     PanelWidget *panel)
-{
-	if (info->type == PANEL_OBJECT_APPLET)
-		panel_applet_frame_change_size (
-			PANEL_APPLET_FRAME (info->widget), panel->sz);
-}
-
-static void
-size_change_foreach(GtkWidget *w, gpointer data)
-{
-	AppletInfo *info = g_object_get_data (G_OBJECT (w), "applet_info");
-	PanelWidget *panel = data;
-	
-	size_change(info,panel);
-}
-
-
-static void
-panel_size_change (GtkWidget *widget, gpointer data)
-{
-	gtk_container_foreach(GTK_CONTAINER(widget), size_change_foreach,
-			      widget);
-}
-
 void
 back_change (AppletInfo  *info,
 	     PanelWidget *panel)
 {
+	PanelAppletFrame    *frame;
+	PanelBackgroundType  type;
+
 	switch (info->type) {
 	case PANEL_OBJECT_APPLET:
-		panel_applet_frame_change_background (
-			PANEL_APPLET_FRAME (info->widget), panel->background.type);
+		frame = PANEL_APPLET_FRAME (info->widget);
+		type = panel->background.type;
+
+		PANEL_APPLET_FRAME_GET_CLASS (frame)->change_background (frame, type);
 		break;
 	case PANEL_OBJECT_MENU_BAR:
 	case PANEL_OBJECT_USER_MENU:
-		panel_menu_bar_object_change_background (PANEL_MENU_BAR_OBJECT (info->widget));
-		break;
 	case PANEL_OBJECT_SEPARATOR:
-		panel_separator_change_background (PANEL_SEPARATOR (info->widget));
 		break;
 	default:
 		break;
@@ -190,7 +163,6 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 	info = g_object_get_data (G_OBJECT (applet), "applet_info");
 
 	orientation_change(info,PANEL_WIDGET(widget));
-	size_change(info,PANEL_WIDGET(widget));
 	back_change(info,PANEL_WIDGET(widget));
 }
 
@@ -337,11 +309,16 @@ panel_popup_menu (PanelToplevel *toplevel,
 	panel_data   = g_object_get_data (G_OBJECT (toplevel), "PanelData");
 
 	current_event = gtk_get_current_event ();
+	if (!current_event)
+		return FALSE;
+
 	if (current_event->type == GDK_BUTTON_PRESS)
 		panel_data->insert_pack_type = panel_widget_get_insert_pack_type_at_cursor (panel_widget);
 	else
 		panel_data->insert_pack_type = PANEL_OBJECT_PACK_START;
-	
+
+	gdk_event_free (current_event);
+
 	menu = make_popup_panel_menu (panel_widget);
 	if (!menu)
 		return FALSE;
@@ -1291,10 +1268,6 @@ panel_widget_setup(PanelWidget *panel)
 			  "back_change",
 			  G_CALLBACK (panel_back_change),
 			  NULL);
-	g_signal_connect (G_OBJECT (panel),
-			  "size_change",
-			  G_CALLBACK (panel_size_change),
-			  NULL);
 }
 
 PanelData *
@@ -1399,8 +1372,8 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 						  "settings are lost."));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				GTK_STOCK_DELETE, GTK_RESPONSE_OK,
+				_("_Cancel"), GTK_RESPONSE_CANCEL,
+				_("_Delete"), GTK_RESPONSE_OK,
 				NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
